import Koa from 'koa'
import dotenv from 'dotenv'
import route from 'koa-route'
import Debug from 'debug'
import koaBody from 'koa-body'
import func from './func'

dotenv.config()
console.log = Debug('invoiceIssuer:app.ts')

const app = new Koa()
app.use(koaBody())

/**
 * GET /
 * @summary 返回欢迎信息。通常用于检查服务器是否正常运行。
 * @param {Koa.Context} ctx - Koa context object
 */
const getRoot = route.get('/', (ctx) => {
    ctx.body = 'Hello World'
})


const postPayer = route.post('/payer', async (ctx) => {
	// TODO: 请求头验证 bearer token
	
	const { name, address, email, abn } = ctx.request.body
	if (!name || !address || !email) {
		ctx.throw(400, 'required_fields_missing')
	}

	try {
		const payer = await func.createPayer(name, address, email, abn)
		ctx.body = payer
	} catch (e) {
		if (e instanceof HttpError) {
			ctx.status = e.status
			ctx.body = e.message
		} else {
			console.error(e)
			ctx.throw(500, 'unknown_issues')
		}
	}
})

// 导出路由
export { getRoot, postPayer }

const port = parseInt(process.env.PORT ?? '3000')
app.listen(port, () => {
    /**
     * Server listening callback
     * @summary Logs the server start message
     */
    console.log(`Server is running at http://localhost:${port}`)
})